<p align="center">
 <h1>
  <img width="250px" src="docs/web/static/img/logo.svg" alt="Mephisto" />
 </h1>
</p>

[![code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![code style: prettier](https://img.shields.io/badge/code_style-prettier-ff69b4.svg)](https://github.com/prettier/prettier)

Mephisto makes crowdsourcing easier.

We provide a platform for launching, monitoring, and reviewing your crowdsourcing tasks. Tasks made on Mephisto can easily be open sourced as part of other projects. Like the [chess-playing automaton](https://en.wikipedia.org/wiki/Mephisto_(automaton)) we've adopted the name from, Mephisto hides the complexity of projects that need human interaction or input.

You can find complete details about the project on our [docs website](https://mephisto.ai).

## Quickstart

[Get started in 10 minutes](https://mephisto.ai/docs/guides/quickstart)

## Changelog

## Want to help?

Check out our [guidelines for contributing](https://github.com/facebookresearch/Mephisto/blob/main/CONTRIBUTING.md) and then take a look at some of our tagged issues: [good first issue](https://github.com/facebookresearch/Mephisto/labels/good%20first%20issue), [help wanted](https://github.com/facebookresearch/Mephisto/labels/help%20wanted).

For library authors, you may also find the [how to contribute](https://mephisto.ai/docs/guides/how_to_contribute/getting_started) documentation helpful.


## License
Mephisto is MIT licensed. See the LICENSE file for details.
